@@ -32,7 +32,7 @@
 *   WCSLIB by drawing native and celestial coordinate grids for Bonne's
 *   projection.
 *
-*   $Id: tcel1.f,v 2.0 1995/09/12 06:30:24 mcalabre Exp $
+*   $Id: tcel.f,v 2.1 1996/05/07 21:09:50 mcalabre Exp $
 *-----------------------------------------------------------------------
       INTEGER   CI, CRVAL1, CRVAL2, IERR, ILAT, ILNG, J, LATPOL, LNGPOL
       REAL      XR(512), YR(512)
@@ -40,6 +40,12 @@
      *          THETA, X, Y
       CHARACTER PCODE*3, TEXT*72
 *-----------------------------------------------------------------------
+      WRITE (6, 5)
+ 5    FORMAT (/,'Testing WCSLIB celestial coordinate transformation ',
+     *          'routines',/,
+     *          '---------------------------------------------------',
+     *          '--------')
+
 *     Set up Bonne's projection with conformal latitude at +35.
       PCODE = 'BON'
 
@@ -101,7 +107,7 @@
 
 *              Write a descriptive title.
                TEXT = PCODE // ' projection - 15 degree graticule'
-               WRITE (6, '(A)') TEXT
+               WRITE (6, '(/,A)') TEXT
                CALL PGTEXT (-180.0, -100.0, TEXT)
 
                WRITE (TEXT, 20) CELEST(1), CELEST(2)
